@@ -6,6 +6,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "timelabels.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "agenda.h"
 #include "prefs.h"
 #include "timelabelszone.h"
@@ -161,7 +163,7 @@ int TimeLabels::yposToCell(const int ypos) const
         return 0;
     }
 
-    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), QTimeZone::LocalTime).toUTC();
     const int beginning // the hour we start drawing with
         = !mTimezone.isValid() ? 0 : (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
@@ -228,7 +230,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     // We won't paint parts that aren't visible
     const int cy = -y(); // y() returns a negative value.
 
-    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), QTimeZone::LocalTime).toUTC();
     const int beginning =
         !mTimezone.isValid() ? 0 : (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
@@ -365,37 +367,37 @@ QString TimeLabels::headerToolTip() const
     QDateTime now = QDateTime::currentDateTime();
     QString toolTip;
 
-    toolTip += QLatin1String("<qt>");
+    toolTip += "<qt>"_L1;
     toolTip += i18nc("title for timezone info, the timezone id and utc offset",
                      "<b>%1 (%2)</b>",
                      i18n(mTimezone.id().constData()),
                      KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
-    toolTip += QLatin1String("<hr>");
+    toolTip += "<hr>"_L1;
     toolTip += i18nc("heading for timezone display name", "<i>Name:</i> %1", mTimezone.displayName(now, QTimeZone::LongName));
-    toolTip += QLatin1String("<br/>");
+    toolTip += "<br/>"_L1;
 
     if (mTimezone.territory() != QLocale::AnyCountry) {
         toolTip += i18nc("heading for timezone country", "<i>Country:</i> %1", QLocale::territoryToString(mTimezone.territory()));
-        toolTip += QLatin1String("<br/>");
+        toolTip += "<br/>"_L1;
     }
 
     auto abbreviations = QStringLiteral("&nbsp;");
     const auto lst = mTimezone.transitions(now, now.addYears(1));
     for (const auto &transition : lst) {
         abbreviations += transition.abbreviation;
-        abbreviations += QLatin1String(",&nbsp;");
+        abbreviations += ",&nbsp;"_L1;
     }
     abbreviations.chop(7);
     if (!abbreviations.isEmpty()) {
         toolTip += i18nc("heading for comma-separated list of timezone abbreviations", "<i>Abbreviations:</i>");
         toolTip += abbreviations;
-        toolTip += QLatin1String("<br/>");
+        toolTip += "<br/>"_L1;
     }
     const QString timeZoneComment(mTimezone.comment());
     if (!timeZoneComment.isEmpty()) {
         toolTip += i18nc("heading for the timezone comment", "<i>Comment:</i> %1", timeZoneComment);
     }
-    toolTip += QLatin1String("</qt>");
+    toolTip += "</qt>"_L1;
 
     return toolTip;
 }
@@ -407,14 +409,14 @@ bool TimeLabels::event(QEvent *event)
         const int cell = yposToCell(helpEvent->pos().y());
 
         QString toolTip;
-        toolTip += QLatin1String("<qt>");
+        toolTip += "<qt>"_L1;
         toolTip += i18nc("[hour of the day][am/pm/00] [timezone id (timezone-offset)]",
                          "%1%2<br/>%3 (%4)",
                          cellToHour(cell),
                          cellToSuffix(cell),
                          i18n(mTimezone.id().constData()),
                          KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
-        toolTip += QLatin1String("</qt>");
+        toolTip += "</qt>"_L1;
 
         QToolTip::showText(helpEvent->globalPos(), toolTip, this);
 
