@@ -6,6 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "multiagendaview.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "agenda/agenda.h"
 #include "agenda/agendaview.h"
@@ -154,7 +155,7 @@ MultiAgendaView::MultiAgendaView(const CalendarFactory::Ptr &factory, QWidget *p
 {
     auto topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
-    topLevelLayout->setContentsMargins(0, 0, 0, 0);
+    topLevelLayout->setContentsMargins({});
 
     // agendaheader is a VBox layout with default spacing containing two labels,
     // so the height is 2 * default font height + 2 * default vertical layout spacing
@@ -182,7 +183,7 @@ MultiAgendaView::MultiAgendaView(const CalendarFactory::Ptr &factory, QWidget *p
         auto timeLabelsBox = new QWidget(d->mLeftSplitter);
         auto timeLabelsBoxLayout = new QVBoxLayout(timeLabelsBox);
         timeLabelsBoxLayout->setSpacing(0);
-        timeLabelsBoxLayout->setContentsMargins(0, 0, 0, 0);
+        timeLabelsBoxLayout->setContentsMargins({});
 
         d->mTimeLabelsZone = new TimeLabelsZone(timeLabelsBox, PrefsPtr(new Prefs()));
         timeLabelsBoxLayout->addWidget(d->mTimeLabelsZone);
@@ -204,7 +205,7 @@ MultiAgendaView::MultiAgendaView(const CalendarFactory::Ptr &factory, QWidget *p
 
         d->mTopBox = new QWidget(d->mScrollArea->viewport());
         auto mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
-        mTopBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
+        mTopBoxHBoxLayout->setContentsMargins({});
         d->mScrollArea->setWidget(d->mTopBox);
 
         topLevelLayout->addWidget(d->mScrollArea, 100);
@@ -506,7 +507,7 @@ AgendaView *MultiAgendaViewPrivate::createView(const QString &title)
     auto box = new QWidget(mTopBox);
     mTopBox->layout()->addWidget(box);
     auto layout = new QVBoxLayout(box);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
     auto av = new AgendaView(q->preferences(), q->startDateTime().date(), q->endDateTime().date(), true, true, q);
     layout->addWidget(av);
     av->setIncidenceChanger(q->changer());
@@ -769,7 +770,7 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
             auto checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
-            const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
+            const QString groupName = configGroup.name() + "_subView_"_L1 + QString::number(i);
             const KConfigGroup group = configGroup.config()->group(groupName);
 
             if (!d->mSelectionSavers.contains(groupName)) {
@@ -794,7 +795,7 @@ void MultiAgendaView::doSaveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("ColumnTitles", d->mCustomColumnTitles);
     int idx = 0;
     for (KCheckableProxyModel *checkableProxyModel : std::as_const(d->mCollectionSelectionModels)) {
-        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(idx);
+        const QString groupName = configGroup.name() + "_subView_"_L1 + QString::number(idx);
         KConfigGroup group = configGroup.config()->group(groupName);
         ++idx;
         // TODO never used ?
