@@ -11,6 +11,7 @@
 */
 
 #include "todoview.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "calendarview_debug.h"
 #include "coloredtodoproxymodel.h"
@@ -298,7 +299,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     connect(mView, &TodoViewView::customContextMenuRequested, this, &TodoView::contextMenu);
     connect(mView, &TodoViewView::doubleClicked, this, &TodoView::itemDoubleClicked);
 
-    connect(mView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &TodoView::selectionChanged);
+    connect(mView->selectionModel(), &QItemSelectionModel::currentChanged, this, &TodoView::currentChanged);
 
     mQuickAdd = new TodoViewQuickAddLine(this);
     mQuickAdd->setClearButtonEnabled(true);
@@ -331,7 +332,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     }
 
     auto layout = new QGridLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
     if (!mSidebarView) {
         layout->addWidget(mQuickSearch, 0, 0, 1, 2);
     }
@@ -415,7 +416,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                   i18nc("@action:inmenu", "Create Event from To-do"),
                                   this,
                                   qOverload<>(&TodoView::createEvent));
-    a->setObjectName(QLatin1StringView("createevent"));
+    a->setObjectName("createevent"_L1);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -423,7 +424,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                   i18nc("@action:inmenu", "Create Note for To-do"),
                                   this,
                                   qOverload<>(&TodoView::createNote));
-    a->setObjectName(QLatin1StringView("createnote"));
+    a->setObjectName("createnote"_L1);
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -793,7 +794,7 @@ void TodoView::contextMenu(QPoint pos)
         case Akonadi::TodoModel::DueDateColumn:
             mMovePopupMenu->popup(mView->viewport()->mapToGlobal(pos));
             break;
-            case Akonadi::TodoModel::CategoriesColumn:
+        case Akonadi::TodoModel::CategoriesColumn:
             createCategoryPopupMenu()->popup(mView->viewport()->mapToGlobal(pos));
             break;
         default:
@@ -805,16 +806,15 @@ void TodoView::contextMenu(QPoint pos)
     }
 }
 
-void TodoView::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+void TodoView::currentChanged(const QModelIndex &current, const QModelIndex &previous)
 {
-    Q_UNUSED(deselected)
-    QModelIndexList selection = selected.indexes();
-    if (selection.isEmpty() || !selection[0].isValid()) {
+    Q_UNUSED(previous);
+    if (!current.isValid()) {
         Q_EMIT incidenceSelected(Akonadi::Item(), QDate());
         return;
     }
 
-    const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = current.data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
 
     if (selectedIncidenceDates().isEmpty()) {
         Q_EMIT incidenceSelected(todoItem, QDate());
@@ -1230,7 +1230,8 @@ void TodoView::resizeColumns()
     // Calculate size of non-stretchable columns:
     int size = 0;
     for (int i = 0; i < Akonadi::TodoModel::ColumnCount; ++i) {
-        if (!mView->isColumnHidden(i) && i != Akonadi::TodoModel::SummaryColumn && i != Akonadi::TodoModel::DescriptionColumn && i != Akonadi::TodoModel::CategoriesColumn) {
+        if (!mView->isColumnHidden(i) && i != Akonadi::TodoModel::SummaryColumn && i != Akonadi::TodoModel::DescriptionColumn
+            && i != Akonadi::TodoModel::CategoriesColumn) {
             size += mView->columnWidth(i);
         }
     }
